# Generated by Django 2.1.4 on 2019-03-27 20:32

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [("zengo", "0001_initial")]

    operations = [
        migrations.CreateModel(
            name="Attachment",
            fields=[
                ("id", models.BigAutoField(primary_key=True, serialize=False)),
                ("zendesk_id", models.BigIntegerField(unique=True)),
                ("file_name", models.TextField()),
                ("content_url", models.URLField()),
                ("content_type", models.TextField()),
                ("size", models.BigIntegerField()),
                ("width", models.PositiveIntegerField(blank=True, null=True)),
                ("height", models.PositiveIntegerField(blank=True, null=True)),
                ("inline", models.BooleanField()),
            ],
        ),
        migrations.CreateModel(
            name="Photo",
            fields=[
                ("id", models.BigAutoField(primary_key=True, serialize=False)),
                ("zendesk_id", models.BigIntegerField(unique=True)),
                ("file_name", models.TextField()),
                ("content_url", models.URLField()),
                ("content_type", models.TextField()),
                ("size", models.BigIntegerField()),
                ("width", models.PositiveIntegerField(blank=True, null=True)),
                ("height", models.PositiveIntegerField(blank=True, null=True)),
                (
                    "attachment",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="photos",
                        to="zengo.Attachment",
                    ),
                ),
            ],
        ),
        migrations.AddField(
            model_name="comment",
            name="html_body",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="comment",
            name="plain_body",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="attachment",
            name="comment",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="attachments",
                to="zengo.Comment",
            ),
        ),
    ]
