# Generated by Django 2.1.4 on 2019-06-27 16:11

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("zengo", "0002_attachments")]

    operations = [
        migrations.AlterField(
            model_name="attachment",
            name="content_url",
            field=models.TextField(validators=[django.core.validators.URLValidator()]),
        ),
        migrations.AlterField(
            model_name="photo",
            name="content_url",
            field=models.TextField(validators=[django.core.validators.URLValidator()]),
        ),
        migrations.AlterField(
            model_name="ticket",
            name="url",
            field=models.TextField(
                blank=True,
                null=True,
                validators=[django.core.validators.URLValidator()],
            ),
        ),
    ]
